==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AArrayReference.h <==
// public final class soot.jimple.parser.node.AArrayReference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f249f5157a5bcce4 soot_jimple_parser_node_AArrayReference
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 2a4c678c0b032ea5 soot_jimple_parser_node_PReference

// header file dependencies
// @dep_header soot_jimple_parser_node_PReference

#include "soot/jimple/parser/node/PReference.h"

#ifndef _JC_soot_jimple_parser_node_AArrayReference_H_
#define _JC_soot_jimple_parser_node_AArrayReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayRef$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AArrayReference$sub_refs	_jc_soot_jimple_parser_node_AArrayReference$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs	_jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$refs	_jc_soot_jimple_parser_node_AArrayReference$refs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$nonrefs	_jc_soot_jimple_parser_node_AArrayReference$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$object	_jc_soot_jimple_parser_node_AArrayReference$object;

typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vmethods	_jc_soot_jimple_parser_node_AArrayReference$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vtable	_jc_soot_jimple_parser_node_AArrayReference$vtable;
typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vtype	_jc_soot_jimple_parser_node_AArrayReference$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AArrayReference$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
extern void _jc_soot_jimple_parser_node_AArrayReference$method$_init$1bcbfce07c11936b(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AArrayReference$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AArrayReference$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
extern struct _jc_soot_jimple_parser_node_PArrayRef$object *_jc_soot_jimple_parser_node_AArrayReference$method$getArrayRef$5b204c3f82838413(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
extern void _jc_soot_jimple_parser_node_AArrayReference$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AArrayReference$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AArrayReference$method$setArrayRef$0c70d59a4d332272(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AArrayReference$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$getArrayRef$5b204c3f82838413;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$setArrayRef$0c70d59a4d332272;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AArrayReference$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
	struct _jc_soot_jimple_parser_node_PArrayRef$object	*(*getArrayRef$5b204c3f82838413)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setArrayRef$0c70d59a4d332272)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AArrayReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PReference$vmethods	soot_jimple_parser_node_PReference;
	_jc_soot_jimple_parser_node_AArrayReference$vmethods	soot_jimple_parser_node_AArrayReference;
};

// Vtype
struct _jc_soot_jimple_parser_node_AArrayReference$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AArrayReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AArrayReference$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayRef$object	*__5farrayRef__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AArrayReference$refs {
    _jc_soot_jimple_parser_node_AArrayReference$sub_refs	soot_jimple_parser_node_AArrayReference;
    _jc_soot_jimple_parser_node_PReference$sub_refs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AArrayReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PReference$sub_nonrefs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs	soot_jimple_parser_node_AArrayReference;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AArrayReference$object {
	_jc_soot_jimple_parser_node_AArrayReference$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AArrayReference$vtype	*vtype;
	_jc_soot_jimple_parser_node_AArrayReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AArrayReference$vtype _jc_soot_jimple_parser_node_AArrayReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AArrayReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AArrayReference$class_object;

#endif	/* _JC_soot_jimple_parser_node_AArrayReference_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AArrayReference.h <==
// public final class soot.jimple.parser.node.AArrayReference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f249f5157a5bcce4 soot_jimple_parser_node_AArrayReference
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 2a4c678c0b032ea5 soot_jimple_parser_node_PReference

// header file dependencies
// @dep_header soot_jimple_parser_node_PReference

#include "soot/jimple/parser/node/PReference.h"

#ifndef _JC_soot_jimple_parser_node_AArrayReference_H_
#define _JC_soot_jimple_parser_node_AArrayReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayRef$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AArrayReference$sub_refs	_jc_soot_jimple_parser_node_AArrayReference$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs	_jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$refs	_jc_soot_jimple_parser_node_AArrayReference$refs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$nonrefs	_jc_soot_jimple_parser_node_AArrayReference$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AArrayReference$object	_jc_soot_jimple_parser_node_AArrayReference$object;

typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vmethods	_jc_soot_jimple_parser_node_AArrayReference$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vtable	_jc_soot_jimple_parser_node_AArrayReference$vtable;
typedef const struct _jc_soot_jimple_parser_node_AArrayReference$vtype	_jc_soot_jimple_parser_node_AArrayReference$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AArrayReference$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AArrayReference$method$_init$1bcbfce07c11936b(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AArrayReference$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AArrayReference$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PArrayRef$object *_jc_soot_jimple_parser_node_AArrayReference$method$getArrayRef$5b204c3f82838413(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AArrayReference$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AArrayReference$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AArrayReference$method$setArrayRef$0c70d59a4d332272(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AArrayReference$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$getArrayRef$5b204c3f82838413;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$setArrayRef$0c70d59a4d332272;
extern _jc_method _jc_soot_jimple_parser_node_AArrayReference$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AArrayReference$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PArrayRef$object	*(*getArrayRef$5b204c3f82838413)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setArrayRef$0c70d59a4d332272)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *, struct _jc_soot_jimple_parser_node_PArrayRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AArrayReference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AArrayReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PReference$vmethods	soot_jimple_parser_node_PReference;
	_jc_soot_jimple_parser_node_AArrayReference$vmethods	soot_jimple_parser_node_AArrayReference;
};

// Vtype
struct _jc_soot_jimple_parser_node_AArrayReference$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AArrayReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AArrayReference$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayRef$object	*__5farrayRef__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AArrayReference$refs {
    _jc_soot_jimple_parser_node_AArrayReference$sub_refs	soot_jimple_parser_node_AArrayReference;
    _jc_soot_jimple_parser_node_PReference$sub_refs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AArrayReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PReference$sub_nonrefs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_AArrayReference$sub_nonrefs	soot_jimple_parser_node_AArrayReference;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AArrayReference$object {
	_jc_soot_jimple_parser_node_AArrayReference$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AArrayReference$vtype	*vtype;
	_jc_soot_jimple_parser_node_AArrayReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AArrayReference$vtype _jc_soot_jimple_parser_node_AArrayReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AArrayReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AArrayReference$class_object;

#endif	/* _JC_soot_jimple_parser_node_AArrayReference_H_ */
